
local addonName, addonData = ...

addonData.PlayerNames = {}

addonData.bnNameFormat = "%s"
addonData.playerBNFormat = "|HBNplayer:%s|h" .. addonData.bnNameFormat .. "%s|h"
addonData.playerBNPattern = "|HBNplayer:(.-)|h%[(|Kf(%d+).-)%](.*)|h"

-- Color an individual Presence Name and return the value to be added to the table
addonData.ColorPresenceName = function(self,presenceID,dispName)
	if not presenceID then
		return dispName
	end

	local toonInfo1, toonName, client, realmName, realmID, faction, race, class, toonInfo9, zoneName, level, 
			gameText, broadcastText, broadcastTime, toonInfo15, presenceID = BNGetToonInfo(presenceID)

	local classToken = self.ClassNames[class]
	local color = classToken and RAID_CLASS_COLORS[classToken]
	local colorHex = self:RGB_TO_HEX(color,FRIENDS_BNET_NAME_COLOR)

	if colorHex then
		if toonName and self.showToonName then
			if realmName and self.showRealmName then
				return string.format("|cff%s%s (%s-%s)|r",colorHex,dispName,toonName,realmName)
			else
				return string.format("|cff%s%s (%s)|r",colorHex,dispName,toonName)
			end
		else
			return string.format("|cff%s%s|r",colorHex,dispName)
		end
	end
end

-- Rebuild a list of your active friends current toons whenever they come online or you enter the world
addonData.BuildPresenceTable = function(self)
	self.PlayerNames = self.PlayerNames or {}
	wipe(self.PlayerNames)
	
	for i = 1, BNGetNumFriends() do
		local presenceID, presenceName, battleTag, isBattleTagPresence, toonName, toonID, client, isOnline, lastOnline, 
				isAFK, isDND, messageText, noteText, isRIDFriend, broadcastTime, canSoR = BNGetFriendInfo(i)

		if isOnline and toonID and client == BNET_CLIENT_WOW then
			local dispName = presenceName
			if isBattleTagPresence and battleTag and self.showBattleTag then
				dispName = battleTag
			end
			self.PlayerNames[presenceID] = self:ColorPresenceName(presenceID,dispName)
		end
	end

end

-- Customize the selected chat frame
addonData.CustomizeChatFrame = function(self,chatFrame)
	self[chatFrame] = self[chatFrame] or {}
	if ( not self[chatFrame].AddMessage ) then
		self[chatFrame].AddMessage = chatFrame.AddMessage
		chatFrame.AddMessage = self.AddMessage
	end
end

-- Customize the add message function with our own changes
addonData.AddMessage = function(chatFrame, message, ...)
	if type(message) == "string" then
		local presenceData, presenceName, presenceID, presenceExtra = string.match(message, addonData.playerBNPattern)
		if presenceName then
			if presenceID and not ( addonData.PlayerNames[presenceID] ) then
				addonData.PlayerNames[presenceID] = addonData:ColorPresenceName(presenceID,presenceName)
			end
			local link = string.format(addonData.playerBNFormat, presenceData, addonData.PlayerNames[presenceID], presenceExtra or "")
			message = string.gsub(message, addonData.playerBNPattern, link)
		end
	end
	addonData[chatFrame].AddMessage(chatFrame,message, ...)
end

